# This package is arch-specific, because it computes properties of the system
# (such as endianness) and stores them in generated header files.  Hence, the
# files DO vary by platform.  However, there is no actual compiled code, so
# turn off debuginfo generation.
%global debug_package %{nil}

Name:           fflas-ffpack
Version:        1.6.0
Release:        2%{?dist}
Summary:        Finite field linear algebra subroutines

Group:          Development/Libraries
# %%{_bindir}/fflasffpack-config is CeCILL-B; other files are LGPLv2+
License:        LGPLv2+ and CeCILL-B
URL:            http://linalg.org/projects/fflas-ffpack
Source0:        http://linalg.org/%{name}-%{version}.tar.gz

# Patch from upstream discussion list.  Fixes building with debug.
Patch1:         %{name}-debug.patch

BuildRequires:  atlas-devel
BuildRequires:  doxygen
BuildRequires:  givaro-devel
BuildRequires:  gmp-devel
BuildRequires:  tex(latex)

# Although there are references to linbox-devel files in this package,
# linbox-devel Requires fflas-ffpack-devel, not the other way around.

%description
The FFLAS-FFPACK library provides functionality for dense linear algebra
over word size prime finite fields.

%package devel
Summary:        Header files for developing with fflas-ffpack
Group:          Development/Libraries
Requires:       atlas-devel%{?_isa}, givaro-devel%{?_isa}, gmp-devel%{?_isa}

%description devel
The FFLAS-FFPACK library provides functionality for dense linear algebra
over word size prime finite fields.  This package provides the header
files for developing applications that use FFLAS-FFPACK.

%package doc
Summary:        API documentation for fflas-ffpack
Group:          Documentation
Requires:       %{name}-devel%{?_isa} = %{version}-%{release}

%description doc
API documentation for fflas-ffpack.

%prep
%setup -q
%patch1 -p1

# Fix character encodings
for f in AUTHORS TODO; do
  iconv -f iso8859-1 -t utf-8 $f > $f.utf8
  touch -r $f $f.utf8
  mv -f $f.utf8 $f
done

# Fix the FSF's address
for f in `grep -FRl 'Temple Place' .`; do
  sed -i.orig \
    's/59 Temple Place, Suite 330, Boston, MA  02111-1307/51 Franklin Street, Suite 500, Boston, MA  02110-1335/' \
    $f
  touch -r $f.orig $f
  rm -f $f.orig
done

%build
%configure --docdir=%{_docdir}/fflas-ffpack-%{version} --disable-static \
  --enable-optimization --enable-doc --with-cblas=%{_libdir}/atlas \
  --with-lapack=%{_libdir}/atlas
make %{?_smp_mflags}

# Build the developer documentation, too
cd doc
doxygen DoxyfileDev
cd ..

%install
make install DESTDIR=$RPM_BUILD_ROOT

# Documentation is installed in the wrong place
rm -fr $RPM_BUILD_ROOT%{_prefix}/docs

# Don't want these files in with the HTML files
rm -f doc/fflas-ffpack-html/{AUTHORS,COPYING,INSTALL}

%check
make check

%files devel
%doc AUTHORS ChangeLog COPYING README TODO
%{_bindir}/fflas-ffpack-config
%{_includedir}/fflas-ffpack

%files doc
%doc doc/fflas-ffpack.html doc/fflas-ffpack-html doc/fflas-ffpack-dev-html

%changelog
* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Jul 3 2012 pcpa <paulo.cesar.pereira.de.andrade@gmail.com> - 1.6.0-1
- Update to latest upstream release.
- Remove gcc 4.7 patch already applied to upstream tarball.
- Rediff fflas-ffpack-debug patch.
- Remove fflas-ffpack-inline patch already applied to upstream tarball.
- Remove fflas-ffpack-64bit patch already applied to upstream tarball.

* Thu May  3 2012 Jerry James <loganjerry@gmail.com> - 1.4.3-3
- Add debug, inline, and 64bit patches

* Mon Jan  9 2012 Jerry James <loganjerry@gmail.com> - 1.4.3-2
- Rebuild for GCC 4.7

* Tue Nov  1 2011 Jerry James <loganjerry@gmail.com> - 1.4.3-1
- New upstream version
- Tests have been fixed; restore %%check script

* Mon Aug 29 2011 Jerry James <loganjerry@gmail.com> - 1.4.2-1
- New upstream version
- Tests are hopelessly broken; disable for now

* Thu May 26 2011 Jerry James <loganjerry@gmail.com> - 1.4.1-2
- Issues found on review:
- Fix license tag (fflasffpack-config is CeCILL-B)
- Add -doc subpackage
- More bad FSF addresses

* Tue May 24 2011 Jerry James <loganjerry@gmail.com> - 1.4.1-1
- Initial RPM
